@@ -2,6 +2,7 @@ from os import path
 import logging
 from dataclasses import dataclass
 import glob
+import errno
 
 from ansidocs.classes.abstract_project_part import AbstractProjectPart
 from ansidocs.classes.abstract_project_part import AbstractDirContent
@@ -22,7 +23,11 @@ class Roles(AbstractProjectPart):
         super().__init__(project_root=project_root, layout=layout)
         self.root_dir = path.abspath(path.join(self.project_root, layout.part_paths['roles']))
         if not path.exists(self.root_dir):
-            raise FileNotFoundError(f"Unable to find Defaults project part directory {self.root_dir}")
+            raise FileNotFoundError(
+                errno.ENOENT,
+                f"Unable to find defaults project part directory {self.root_dir}",
+                self.root_dir)
+
 
     def get_content(self):
         content = []
